@@ -8,7 +8,8 @@ import datetime
 
 class Command(BaseCommand):
     option_list = BaseCommand.option_list + (
-        make_option('--days', action='store',  dest='cutoff'),
+        make_option('--days', action='store', dest='days'),
+        make_option('--logger', action='store', dest='logger')
     )
     
     help = 'Cleans up old entries in the log.'
@@ -16,5 +17,9 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         ts = datetime.datetime.now() - datetime.timedelta(days=options.get('days', 30))
         
-        ErrorBatch.objects.filter(last_seen__lte=ts).delete()
-        Error.objects.filter(datetime__lte=ts).delete()
\ No newline at end of file
+        base_kwargs = {}
+        if options.get('logger'):
+            base_kwargs['logger'] = options['logger']
+        
+        ErrorBatch.objects.filter(last_seen__lte=ts, **base_kwargs).delete()
+        Error.objects.filter(datetime__lte=ts, **base_kwargs).delete()
\ No newline at end of file
