@@ -116,7 +116,7 @@ class ErrorBatch(Model):
                 data = dict()
 
             extra = dict(
-                url=request.build_absolute_uri(),
+                url=request and request.build_absolute_uri() or None,
                 data=data,
             )
 
@@ -126,7 +126,7 @@ class ErrorBatch(Model):
                 Error.objects.create_from_exception(**extra)
         except Exception, exc:
             try:
-                logger.exception(exc)
+                logger.exception(u'Unable to process log entry: %s' % (exc,))
             except Exception, exc:
                 warnings.warn(u'Unable to process log entry: %s' % (exc,))
 
